@@ -9,7 +9,7 @@ Features
 * Download all PDFs referenced in the original PDF
 * Works with local and online pdfs
 * Use as command-line tool or Python package
-* Compatible with Python 3.6 and up
+* Compatible with Python 2 and 3
 
 Usage
 
@@ -25,13 +25,18 @@ linkrot can be used to extract infos from PDF in two ways:
 >>> references_dict = pdf.get_references_as_dict()
 >>> pdf.download_pdfs("target-directory")
 
-https://www.rottingresearch.com
+https://www.metachris.com/linkrot
 
-Copyright (c) 2021, Marshal Miller<marshal@marshalmiller.com>
+Copyright (c) 2021, Marshal Miller <marshal@marshalmiller.com>
 License: GPLv3
 """
-from __future__ import (absolute_import, division,
-                        print_function, unicode_literals)
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+__title__ = "linkrot"
+__version__ = "1.2"
+__author__ = "Marshal Miller"
+__license__ = "MIT"
+__copyright__ = "Copyright 2021 Marshal Miller"
 
 import os
 import sys
@@ -39,17 +44,13 @@ import json
 import shutil
 import logging
 
+
 from .extractor import extract_urls
 from .backends import PDFMinerBackend, TextBackend
 from .downloader import download_urls
 from .exceptions import FileNotFoundError, DownloadError, PDFInvalidError
 from pdfminer.pdfparser import PDFSyntaxError
 
-__title__ = 'linkrot'
-__version__ = '.81'
-__author__ = 'Marshal Miller'
-__license__ = 'Apache 2.0'
-__copyright__ = 'Copyright 2021 Marshal Miller'
 
 IS_PY2 = sys.version_info < (3, 0)
 
@@ -61,8 +62,8 @@ else:
     # Python 3
     from io import BytesIO
     from urllib.request import Request, urlopen
-    unicode = str
 
+    unicode = str
 
 logger = logging.getLogger(__name__)
 
@@ -82,6 +83,7 @@ class linkrot(object):
     >>> print(pdf.get_references())
     >>> pdf.download_pdfs("target-directory")
     """
+
     # Available after init
     uri = None  # Original URI
     fn = None  # Filename part of URI
@@ -113,13 +115,11 @@ class linkrot(object):
                 content = urlopen(Request(uri)).read()
                 self.stream = BytesIO(content)
             except Exception as e:
-                raise DownloadError("Error downloading '%s' (%s)"
-                                    % (uri, unicode(e)))
+                raise DownloadError("Error downloading '%s' (%s)" % (uri, unicode(e)))
 
         else:
             if not os.path.isfile(uri):
-                raise FileNotFoundError("Invalid filename and not an url: '%s'"
-                                        % uri)
+                raise FileNotFoundError("Invalid filename and not an url: '%s'" % uri)
             self.fn = os.path.basename(uri)
             self.stream = open(uri, "rb")
 
@@ -199,8 +199,7 @@ class linkrot(object):
         if not urls:
             return
 
-        dir_referenced_pdfs = os.path.join(target_dir, "%s-referenced-pdfs"
-                                           % self.fn)
+        dir_referenced_pdfs = os.path.join(target_dir, "%s-referenced-pdfs" % self.fn)
         logger.debug("Downloading %s referenced pdfs..." % len(urls))
 
         # Download urls as a set to avoid duplicates
